#!/bin/bash -e
#####
# 在wine目录下生成如下脚本
# 1. killqq.sh：一键kill qq进程，因为退出QQ后，并未正确退出，导致不能再次登录，需要先杀掉
# 2. fix-fonts.sh：一般不会出现中文显示方块，如果出现，执行一下脚本
# 3. fix-webbrowers.sh：设定wine使用linux系统默认浏览器
####

if [ "" = "${work_time}" ]; then export work_time=$(date +%Y-%m-%d_%H-%M-%S); fi

readyWine() {
	#1. 安装wine 1.6
	if [ ! -f /usr/bin/wine ] || [ "`wine --version|grep 1.6`" = "" ]; then
		if [ ! -f /etc/apt/sources.list.d/ubuntu-wine-ppa-precise.list ]; then
			echo "添加wine软件源："
			sudo add-apt-repository ppa:ubuntu-wine/ppa
		fi
		echo "安装wine 1.6："
		sudo apt-get update
		sudo apt-get -y install wine
	fi
	#2. 初始化目录和脚本
	export WINEPREFIX=${HOME}/.wine
	if [ -d "${WINEPREFIX}/drive_c/Program Files (x86)" ]; then
		echo "你安装的是64bit .wine环境，将自动创建32位wine安装QQ."
		export WINEPREFIX=${HOME}/.wine-1.6-32
	fi
	if [ -d "${WINEPREFIX}/drive_c/windows" ] && [ ! -d "${WINEPREFIX}/drive_c/Program Files" ]; then
		rm -rf ${WINEPREFIX}
	fi
	
	echo "wine目录：${WINEPREFIX}"
	if [ ! -d "${WINEPREFIX}" ]; then
		echo "准备wine目录：${WINEPREFIX}"
		export WINEARCH=win32
		wineboot -u

		echo '#!/bin/bash
export WINEPREFIX='${WINEPREFIX}'
winetricks $@' > ${WINEPREFIX}/winetricks.sh

		echo '#!/bin/bash
export WINEPREFIX='${WINEPREFIX}'
wine $@' > ${WINEPREFIX}/wine.sh

		echo '#!/bin/bash
export WINEPREFIX='${WINEPREFIX}'
wine regedit $@' > ${WINEPREFIX}/regedit.sh

		echo '#!/bin/bash
export WINEPREFIX='${WINEPREFIX}'
winecfg' > ${WINEPREFIX}/winecfg.sh

		chmod +x ${WINEPREFIX}/*.sh
	fi
	
	echo "winetricks 准备必要文件："
	echo "	安装IE时，请不要选择安装最新更新"
	echo "	1. riched20 msxml3 ie7 mfc42"
	echo "	2. riched20 msxml6 ie8 vcrun2008"
	echo "请选择1、2(default 2):"
	read tmp
	if [ "$tmp" = "1" ]; then
		winetricks riched20 msxml3 ie7 mfc42 || echo "wine准备完毕."
	else
		winetricks riched20 msxml6 ie8 vcrun2008 || echo "wine准备完毕."
	fi
}
readyQQ() {
	if [ ! -f "${WINEPREFIX}/drive_c/Program Files/Tencent/QQ/Bin/QQ.exe" ]; then
		cache_dir=~/.cache/winetricks/qq
		export cache_file=$cache_dir/QQ2012Beta3-20120810.exe
		if [ ! -f "${cache_file}" ] || [ "`md5sum ${cache_file}|grep a868b4c66c3ab5c726ae5844d923098e`" = "" ]; then
			mkdir -p ${cache_dir}
			echo "下载QQ安装文件："
			gvfs-open ${cache_dir}
			wget -N -c --header='Referer:http://download.tech.qq.com/soft/17/21/85596/index.shtml' "http://softdl1.tech.qq.com/soft/21/QQ2012Beta3-20120810.exe" -P ${cache_dir}/
		fi
		
		wine ${cache_file}
		echo "5s后自动kill QQ安装进程..."
		sleep 5s
		ps -eo 'pid,cmd'|grep '.exe'|grep QQ|sed 's/^\s*//'|cut -f 1 -d' '|xargs kill
	fi
}
readyQQSh() {
	#桌面图标
	if [ ! -f "${WINEPREFIX}/QQ.desktop" ]; then
		echo "生成启动脚本：${WINEPREFIX}/qq.sh"
		echo '#!/bin/bash
	exo-open '${WINEPREFIX}'/QQ.desktop' > ${WINEPREFIX}/qq.sh
		chmod +x ${WINEPREFIX}/qq.sh

		echo '[Desktop Entry]
Name=QQ
Exec=env WINEPREFIX="'${WINEPREFIX}'" wine C:\\\\Program\\ Files\\\\Tencent\\\\QQ\\\\Bin\\\\QQ.exe 
Type=Application
StartupNotify=false
Path='${WINEPREFIX}'/dosdevices/c:/Program Files/Tencent/QQ/Bin/
Icon=B9B9_NewShortcut311_0951773981FA4AB2BC21B7DCEC95892A.0
Terminal=false' > ${WINEPREFIX}/QQ.desktop
	fi
	rm -f ~/桌面/QQ.desktop
	ln -sf ${WINEPREFIX}/QQ.desktop ~/桌面/
	#一键killQQ脚本
	if [ ! -f "${WINEPREFIX}/killqq.sh" ]; then
		echo "#!/bin/bash
qq_proc=\"\`ps -eo 'pid,cmd'|grep '.exe'|grep QQ|sed 's/^\s*//'\`\"
echo \"\$qq_proc\"|cut -f 1 -d' '|xargs kill
echo '杀死：'
echo \$qq_proc
sleep 2s
\`ps -eo 'pid,cmd'|grep '.exe'|grep QQ|sed 's/^\s*//'\`
" > ${WINEPREFIX}/killqq.sh
		chmod +x ${WINEPREFIX}/killqq.sh
	fi
	mkdir -p ~/bin
	ln -sf ${WINEPREFIX}/killqq.sh ~/bin/
	ln -sf ${WINEPREFIX}/killqq.sh ~/桌面/
	
	if [ ! -f "${WINEPREFIX}/fix-fonts.sh" ]; then
		echo '[HKEY_LOCAL_MACHINE\Software\Microsoft\Windows NT\CurrentVersion\Fonts]
"SimSun (TrueType)"="Z:\\usr\\bin\\..\\share\\wine\\fonts\\\\wqy-microhei.ttc"'>${WINEPREFIX}/fonts.reg
		echo '#!/bin/bash
echo "修复中文显示为方块"
sudo ln -s /usr/share/fonts/truetype/wqy/wqy-microhei.ttc /usr/share/wine/fonts/
export WINEPREFIX="'${WINEPREFIX}'"
wine regedit $WINEPREFIX/fonts.reg'>${WINEPREFIX}/fix-fonts.sh
		chmod +x ${WINEPREFIX}/fix-fonts.sh
	fi
	if [ ! -f "${WINEPREFIX}/fix-webbrowers.sh" ]; then
		echo '[HKEY_CLASSES_ROOT\http\shell\open\command]
@="\"C:\\windows\\system32\\winebrowser.exe\" -nohome %1"

[HKEY_CLASSES_ROOT\https\shell\open\command]
@="\"C:\\windows\\system32\\winebrowser.exe\" -nohome %1"'>${WINEPREFIX}/webbrowers.reg
		echo '#!/bin/bash
echo "设定windows默认浏览器为linux的缺省浏览器"
export WINEPREFIX="'${WINEPREFIX}'"
wine regedit $WINEPREFIX/webbrowers.reg'>${WINEPREFIX}/fix-webbrowers.sh
		chmod +x ${WINEPREFIX}/fix-webbrowers.sh
	fi
}

readyWine
readyQQ
readyQQSh
${WINEPREFIX}/fix-webbrowers.sh
exo-open ~/桌面/QQ.desktop >/dev/null 2>/dev/null &
